<?php

use App\Base\Base;

use App\Exception\custom\PayException;
use App\Exception\custom\RefundException;
use App\Services\pay\PayService;
use App\Services\refund\RefundService;
use Api\PhpUtils\Log\FileLog;


class OrderController extends Base
{
    /**
     * 创建支付订单，返回前端ping++的支付信息
     */
    public function payAction()
    {
        try{
            $params = $this->params;
            $user_id    = $params['user_id'];
            $order_id = $params['order_id'];
            $pay_method_id = $params['pay_method_id'] ?? 106;

            $paySrv = new PayService();
            $ret = $paySrv->do_pay($order_id, $user_id, $pay_method_id);

            //兼容C端客户端支付，调整返回结构，ping++ 返回 order，原生：微信、支付宝返回charge
            $result = [];
            $result[] = ['k'=>'order', 'v'=>$ret];
            $this->success(['result'=>$result]);

        }catch (PayException $e) {
            $this->failed($e->getMessage(), $e->getCode());
        } catch (\Exception $e) {
            FileLog::error('pay-service:ping++支付报错', json_encode($params, JSON_UNESCAPED_UNICODE), $e);
            $this->failed($e->getMessage(), $e->getCode());
        }
    }

    public function refundAction() {

        try{
            $params = $this->params;
            $user_id    = $params['user_id'];
            $order_item_id = $params['order_item_id'];

            $refundSrv = new RefundService();
            $ret = $refundSrv->do_refund($order_item_id, $user_id);

            $this->success(['result'=>$ret]);

        }catch (RefundException $e) {
            $this->failed($e->getMessage(), $e->getCode());
        } catch (\Exception $e) {
            FileLog::error('pay-service:ping++退款报错', json_encode($params, JSON_UNESCAPED_UNICODE), $e);
            $this->failed($e->getMessage(), $e->getCode());
        }
    }

    public function write_offAction() {

        try{
            $params = $this->params;
            $life_account_id    = $params['life_account_id'];
            $order_item_id = $params['order_item_id'];

            $refundSrv = new PayService();
            $ret = $refundSrv->write_off($order_item_id, $life_account_id);

            $this->success(['result'=>$ret]);

        }catch (RefundException $e) {
            $this->failed($e->getMessage(), $e->getCode());
        } catch (\Exception $e) {
            FileLog::error('pay-service:核销报错', json_encode($params, JSON_UNESCAPED_UNICODE), $e);
            $this->failed($e->getMessage(), $e->getCode());
        }
    }
}
